function r = calcalldistribs(l,n,ix)
% r = calcalldistribs(l,n,ix)  Calculate all LNA probability distribution vecs.
%      <l> is the filename of LNA file containing phoneme probability 
%      distributions of <n> elements (n=54 by default).  
%      For each segment defined in the LNA, call prbdistrib to caculate 
%      a row distribution-feature-vector, return as a row of r.
%      ix optionally defines a (fake?) index into the lna file.
% 1999mar06 dpwe@icsi.berkeley.edu  uttclass . based on allents. uses readlna.m

if (nargin < 2)
  n = 54;
end
if (nargin < 3)
  [d,ix] = readlna(l,-1,n);
  % ix is returned as a vector of the lengths of all the segments in 
  % the LNA file
end

nsegs = size(ix,2);
% r = zeros(1,nsegs);
r = [];

disp([num2str(nsegs), ' segments to process']);

for s = 1:nsegs
  if rem(s,10)==0
     disp(['seg ', num2str(s)]);
  end
  prbs = readlna(l,s,n,ix);
  % Calculate feature
  rr = prbdistrib(prbs);
  if isempty(r) 
    % We now know the size of the vector - can alloc
    r = zeros(nsegs, size(rr,2));
  end
  r(s,:) = rr;
end

