function r = calcalldyns(l,i,n,ix)
% r = calcalldyns(l,i,n,ix)   Calculate all per-seg avg 'dynamism' values
%      <l> is the filename of LNA file containing phoneme probability 
%      distributions of <n> elements (n=54 by default).  
%      For each segment defined in the LNA, calculate average per-frame
%      dynamism over an <i>-step window i.e. mean(sum((prb(n)-prb(n-i))^2))
%      i.e. the mean square of the 1st-order difference of the probabilities
%      over i timesteps (default: i=1).  This score should be large for real 
%      speech, since it changes frequently and rapidly.  But I'm not sure 
%      we're rewarding rapid rather than gradual changes as much as we should
%       - or are we?
%      Output a row, with one value per segment.
%      ix optionally defines a (fake?) index into the lna file.
% 1999jan01 dpwe@icsi.berkeley.edu  uttclass . based on allents. uses readlna.m

if (nargin < 2)
  i = 1;
end
if (nargin < 3)
  n = 54;
end
if (nargin < 4)
  [d,ix] = readlna(l,-1,n);
  % ix is returned as a vector of the lengths of all the segments in 
  % the LNA file
end

nsegs = size(ix,2);
r = zeros(1,nsegs);

disp([num2str(nsegs), ' segments to process']);

for s = 1:nsegs
  if rem(s,10)==0
     disp(['seg ', num2str(s)]);
  end
  prbs = readlna(l,s,n,ix);
  x = size(prbs,2);
  % Calculate dynamism
  r(s) = mean(sum( (prbs(:,1:(x-1))-prbs(:,2:x)).^2 ));
end

