function r = calcallents(l,n,ix)
% r = calcallents(l,n,ix)   Calculate all per-seg avg entropies for a file
%      <l> is the filename of LNA file containing phoneme probability 
%      distributions of <n> elements (n=54 by default).  
%      For each segment defined in the LNA, calculate average per-frame
%      entropy; Output a row, with one entropy per segment.
%      ix optionally defines a (fake?) index into the lna file.
% 1999jan01 dpwe@icsi.berkeley.edu  uttclass . based on allents. uses readlna.m

if (nargin < 2)
  n = 54;
end

if (nargin < 3)
  [d,ix] = readlna(l,-1,n);
  % ix is returned as a vector of the lengths of all the segments in 
  % the LNA file
end

nsegs = size(ix,2);
r = zeros(1,nsegs);

disp([num2str(nsegs), ' segments to process']);

for s = 1:nsegs
  if rem(s,10)==0
     disp(['seg ', num2str(s)]);
  end
  prbs = readlna(l,s,n,ix);
  % Calculate entropy
  r(s) = mean(sum(prbs.*(-log(prbs)./log(2))));
end

