function r = calcalleratios(h,e,n,p,ix)
% r = calcalleratios(h,e,n,p,ix)   Convert h# probs and unseg energy to ratios
%      e is a text file of per-frame energies (not segmented). 
%      h is the filename of LNA file containing the probabilities of 
%      h# as the first of n probabilities per frame (n=54 by default).  
%      For each segment defined in the LNA, calculate the ratio of frame 
%      energy weighted by h# probability to energy weighted by 1 - p(h#).  
%      p is a count of padding frames added to each LNA segment.  Half 
%      this number are dropped from the start of each seg, half from the 
%      end (default 0). Output a row, with one ratio score per segment.
%      ix is optionally the precomputed (fake?) index into the lna.
% 1998nov27 dpwe@icsi.berkeley.edu  uttclass .  uses readlna.m

if (nargin < 3)
  n = 54;
end
if (nargin < 4)
  p = 0;
end
if (nargin < 5)
  [d,ix] = readlna(h,-1,n);
  % ix is returned as a vector of the lengths of all the segments in 
  % the LNA file
end

nsegs = size(ix,2);
r = zeros(1,nsegs);

% Open the energy-frames file.  We will read from it sequentially
g = fopen(e,'r');

disp([num2str(nsegs), ' segments to process']);

halfpad = floor(p/2);

for s = 1:nsegs
  if rem(s,10)==0
     disp(['seg ', num2str(s), ' (energy pos=', num2str(ftell(g)),')']);
  end
  ph = readlna(h,s,n,ix);
  nc = size(ph,2);
  % h# is assumed to be the top row.  Also, do pad stripping
  ph = ph(1,halfpad+(1:(nc-p)));
  nc2 = size(ph,2);
  pfe = (fscanf(g, '%f', nc2))';
  if size(pfe,2) ~= size(ph,2)
    disp(['seg ', num2str(s), ' epos=', num2str(ftell(g)), ' hcols=', num2str(size(ph,2)), ' ecols=', num2str(size(pfe,2))]);
  end
  % Actually calculate the eratio
  %r(s) = (ph*pfe')/((1-ph)*pfe');
  r(s) = ((ph*pfe')/sum(ph))/(((1-ph)*pfe')/sum(1-ph));
end

fclose(g);
