function [R,F,M] = classtest(X,D,R0,R1,T0,T1,TH,DS)
% [R,F,M] = classtest(X,D,R0,R1,T0,T1,TH,DS)  Test classification of data
%       X is a set of data rows and D defines which columns to use in 
%       testing.  Use rows defined by index lists R0 and R1 to 
%       'train' two Gaussian classes, then rate the classication 
%       of test data T0 and T1.  R returns a 2x2 matrix where the 
%       rows correspond to T0 and T1, and the columns are the number 
%       classified to the classes of R0 and R1 respectively.
%       If T0 and T1 are missing, report the classification of R0 and R1.
%       TH is a threshold; distance to class 0 must be less than TH*dist
%       to class 1 to be called 0; larger TH increases the number called 0.
%       DS is the scaling applied to the log determinant ratio bias offset
%       (1 by default i.e. Gaussian likelihood ratio biasing).
%       F returns row indexes of false alarms (called 1 when 0) and 
%       M returns row indexes of missed (called 0 when 1).
% 1999jan14 dpwe@icsi.berkeley.edu uttclass
% $Header: $

if (nargin < 5)
  T0 = R0;
  T1 = R1;
end

if (nargin < 7)
  TH = 1;
end

if (nargin < 8)
  DS = 1;
end

% Calculate the gaussian models
[M0,V0] = meancovar(X(R0,D));
[M1,V1] = meancovar(X(R1,D));

% Calculate the covariance determinant bias
dbias = log(det(V1)/det(V0));

% Calculate the distance to the test data
d00 = gaussdist(M0,V0,X(T0,D));
d01 = gaussdist(M1,V1,X(T0,D));
d10 = gaussdist(M0,V0,X(T1,D));
d11 = gaussdist(M1,V1,X(T1,D));

% Report the classification errors
F = find(d00 > TH*d01 + DS*dbias);
M = find(d10 <= TH*d11 + DS*dbias);
R = [sum(d00 <= TH*d01 + DS*dbias),sum(d00 > TH*d01 + DS*dbias);sum(d10 <= TH*d11 + DS*dbias),sum(d10>TH*d11 + DS*dbias)];
