function T = mkstdtemplate(L,S,IX,N)
% T = mkstdtemplate(L,S,IX,N)  Calc a template of average prob dist stdvs
%       L is the name of an LNA file.  S is a list of segments within that 
%       file to read.  IX is the (optional) pre-read index to the file and 
%       N is the number of columns in the file (default: 54).  Read each 
%       indicated segment and calculate the per-segment standard deviation 
%       for each probability stream within each segment.  Strip off column 
%       0 (assumed h#) then normalize the remainder.  T is returned as the 
%       mean and stddev of the data set formed by these normalized stddev 
%       profiles for all the specified segments.  The idea is that this 
%       will be somewhat characteristic of the type of material.
% 1999jan07 dpwe@icsi.berkeley.edu uttclass
% $Header: /n/yam/da/dpwe/projects/uttclass/mkstdtemplate.m,v 1.1 1999/01/15 01:45:56 dpwe Exp dpwe $

if (nargin < 4)
  N = 54;
end
if (nargin < 3)
  IX = [];
end
if (nargin < 2)
  S = [];
end

T = zeros(2,N);

% Index to remove h# from a length-N vector
nohix = 2:N;

n = 0;

if (isempty(IX))
  [p,IX] = readlna(L,-1);
end
if (isempty(S))
  S = 0:(size(IX,2)-1);
end


for seg = S
  [p,IX] = readlna(L,seg,N,IX);
  % Special weighted mean and var, weighting is 1-pr(h#)
  [m,v] = wtdmeanvar(p',(1-p(1,:))');
  d = sqrt(v);
  % Save stats to calc mean and var later
  T(1,:) = T(1,:) + d;
  T(2,:) = T(2,:) + d.*d;
  n = n+1;
end

% Convert to mean and std
T(1,:) = T(1,:)/n;
T(2,:) = sqrt(T(2,:)/n - (T(1,:).*T(1,:)));

% Strip h# channel
T = T(:,nohix);
