function D = prbdistrib(X,H)
% D = prbdistrib(X,H)  Calculate 'distribution features' for an array of probs.
%        X is an array of probabilities, with each row being a different 
%        mutually-exclusive classes and each column a separate time-step
%        (or trial).  H is the index of a 'weighting row' within the 
%        data, such as silence class: columns scoring high in this row 
%        are de-emphasized (weighting is 1-X(H,t)).  
%        Return a vector characterizing the distribution, such as the means 
%        and/or variances of every non-weighting row.  This is used 
%        to calculate a template, and to measure distances to that 
%        template.
% 1999mar06 dpwe@icsi.berkeley.edu  uttclass
% $Header: $

if (nargin < 2)
  H = 1;
end

[m,v] = wtdmeanvar(X',(1-X(H,:))');
D = sqrt(v);

% Maybe we should strip the H channel?  bit of a pain.
